.. _spkg_sage_setup:

sage-setup: Build system of the SageMath library
==========================================================

This is the build system of the Sage library, based on setuptools.

Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`
- :ref:`spkg_jinja2`
- :ref:`spkg_pkgconfig`

Version Information
-------------------

package-version.txt::

    10.4.63

version_requirements.txt::

    passagemath-setup ~= 10.4.63.0


Equivalent System Packages
--------------------------

(none known)

